Project pyfromroot
==================

*initial setup*

The goal is to have a framework to run Python from root\'s CLINT. Why?

-   TH1F and TGraph on TCanvas is superior over python stuff
-   and it is interactive
-   staying in root allows to have a access to histograms and all other
    stuff
